from functools import lru_cache

from ucsschool.apis.utils import LDAPCredentials, LDAPSettings


def remove_prefix(value: str, prefix: str) -> str:
    """
    Removes the given prefix from the given string.

    >>> remove_prefix("prefix-some_string", "prefix-")
    'some_string'

    :param value: The string to remove the prefix from
    :param prefix: The prefix to remove from the string
    :return: The string without the prefix
    :raises ValueError: If the given string does not start with the given prefix
    """
    if not value.startswith(prefix):
        raise ValueError(f"The value {value} must begin with the prefix: {prefix}")
    return value.removeprefix(prefix)


@lru_cache(maxsize=1)
def ldap_settings() -> LDAPSettings:
    """Cached LDAP settings object"""
    return LDAPSettings()


@lru_cache(maxsize=1)
def ldap_credentials() -> LDAPCredentials:
    """Cached LDAP credentials object"""
    return LDAPCredentials(ldap_settings())
